<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Thanks</source>
        <translation>Podziękowania</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="43"/>
        <source>Help us</source>
        <translation>Pomóż nam</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="100"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>jest wieloplatformowym programem do szybkiego tworzenia zrzutów ekranu.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="102"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>Jest to lekki i funkcjonalny program napisany w Qt.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="34"/>
        <source>using Qt %1</source>
        <translation>używa Qt %1</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="105"/>
        <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation>Strona internetowa - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="108"/>
        <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
        <translation>Wydane na licencji &lt;a href=%1&gt;GPL v2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="112"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Prawa autorskie &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="119"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Możesz dołączyć do nas i pomóc nam, jeśli chcesz i lubisz ten program.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="122"/>
        <source>What you can do?</source>
        <translation>Co możesz zrobić?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="125"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>Przetłumacz ScreenGrab na inne języki</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Make suggestions for next releases</source>
        <translation>Podziel się sugestiami na następne wydanie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Report bugs and issues</source>
        <translation>Zgłoś błędy i problemy</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="130"/>
        <source>Bug tracker</source>
        <translation>Śledzenie błędów</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="140"/>
        <source>Translate:</source>
        <translation>Tłumaczenie:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="142"/>
        <source> Brazilian Portuguese translation</source>
        <translation> Tłumaczenie na brazylijski portugalski</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="143"/>
        <source>Marcio Moraes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="145"/>
        <source> Ukrainian translation</source>
        <translation> Tłumaczenie ukraińskie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="146"/>
        <source>Gennadi Motsyo</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="148"/>
        <source> Spanish translation</source>
        <translation> Tłumaczenie hiszpańskie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="149"/>
        <source>Burjans L García D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="151"/>
        <source> Italian translation</source>
        <translation> Tłumaczenie włoskie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="155"/>
        <source>Testing:</source>
        <translation>Testowanie:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="157"/>
        <source>Dual monitor support and other in Linux</source>
        <translation>Wsparcie wielu monitorów i inne na Linuksie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="158"/>
        <source>Dual monitor support in Linux</source>
        <translation>Wsparcie dwóch monitorów na Linuksie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="159"/>
        <source>win32-build [Windows XP and 7]</source>
        <translation>win32-build [Windows XP i 7]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="160"/>
        <source>old win32-build [Windows Vista]</source>
        <translation>stary win32-build [Windows Vista]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="161"/>
        <source>win32-build [Windows 7]</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="182"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>Ścieżka %1 nie istnieje. Czy chcesz ją utworzyć?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="183"/>
        <location filename="../src/core/ui/configwidget.cpp" line="271"/>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="259"/>
        <source>Select directory</source>
        <translation>Wybierz położenie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="270"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>Czy na pewno chcesz przywrócić ustawienia do domyślnych?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="314"/>
        <source>Example: </source>
        <translation>Przykład: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="355"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>Ten klucz jest już używany przez ScreenGrab! Wybierz inny.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="373"/>
        <source>This key is not supported on your system!</source>
        <translation>Ten klucz nie jest obsługiwany przez Twój system!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="393"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="64"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>jest wieloplatformowym programem do szybkiego tworzenia zrzutów ekranu pulpitu.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="68"/>
        <source>Take a fullscreen screenshot</source>
        <translation>Zrób zrzut pełnego ekranu</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="72"/>
        <source>Take a screenshot of the active window</source>
        <translation>Zrób zrzut ekranu aktywnego okna</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="76"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>Zrób zrzut zaznaczonego obszaru ekranu</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="80"/>
        <source>Run the application with a hidden main window</source>
        <translation>Uruchom program z ukrytym głównym oknem</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="450"/>
        <source>Saved</source>
        <translation>Zapisano</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="450"/>
        <source>Saved to </source>
        <translation>Zapisano do </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="472"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>Nazwa zapisanego pliku została skopiowana do schowka</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="478"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>Ścieżka zapisanego pliku została skopiowana do schowka</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="501"/>
        <source>Copied</source>
        <translation>Skopiowano</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="501"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>Zrzut ekranu został skopiowany do schowka</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
        <source>Type:</source>
        <translation>Rodzaj:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
        <source>Type of screenshot</source>
        <translation>Rodzaj zrzutu ekranu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
        <source>Full screen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
        <source>Screen area</source>
        <translation>Fragment ekranu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
        <source>Last selected area</source>
        <translation>Ostatnio zaznaczony obszar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
        <source>Delay:</source>
        <translation>Opóźnienie:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Opóźnienie w sekundach przed wykonaniem zrzutu ekranu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
        <source>Zoom area around mouse</source>
        <translation>Powiększ obszar przy kursorze</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
        <source>No window decoration</source>
        <translation>Bez dekoracji okna</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
        <source>Include mouse pointer</source>
        <translation>Uwzględnij wskaźnik myszy</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
        <source>toolBar</source>
        <translation>pasek narzędzi</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>New</source>
        <translation>Nowy</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="73"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="50"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="51"/>
        <source>Quit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="315"/>
        <source>Screenshot </source>
        <translation>Zrzut ekranu </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="319"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>Kliknij dwukrotnie, aby otworzyć zrzut ekranu w zewnętrznej domyślnej przeglądarce obrazów</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="328"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="459"/>
        <source>Hide</source>
        <translation>Ukryj</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="466"/>
        <source>Show</source>
        <translation>Pokaż</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="519"/>
        <source>%1 Files</source>
        <translation>%1 plików</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="541"/>
        <source>Save As...</source>
        <translation>Zapisz jako…</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="175"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>Kliknij i przeciągnij, aby zaznaczyć obszar,
naciśnij prawym klawiszem myszy, aby dopasować do krawędzi,
kliknij dwukrotnie lub wciśnij Enter,
aby wykonać zrzut ekranu.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="207"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 pikseli </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>Edytuj w innym programie</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>Edytuj w…</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="118"/>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="144"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="568"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="77"/>
        <source>Main</source>
        <translation>Główne</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="82"/>
        <source>Advanced</source>
        <translation>Zaawansowane</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="87"/>
        <source>System tray</source>
        <translation>Zasobnik systemowy</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="92"/>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="116"/>
        <source>Default save directory</source>
        <translation>Domyślny katalog zapisu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="122"/>
        <source>Path to default selection dir for saving</source>
        <translation>Ścieżka domyślnego zapytania o miejsce zapisu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="135"/>
        <source>Browse filesystem</source>
        <translation>Przeglądaj system plików</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="138"/>
        <source>Browse</source>
        <translation>Przeglądaj</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="148"/>
        <source>Default file</source>
        <translation>Domyślny plik</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="161"/>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="168"/>
        <source>Default filename</source>
        <translation>Domyślna nazwa pliku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="179"/>
        <source>Format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="192"/>
        <source>Default saving image format</source>
        <translation>Domyślny format zapisywania obrazów</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="211"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>Kopiuj nazwę pliku do schowka po zapisaniu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="225"/>
        <source>Do not copy</source>
        <translation>Nie kopiuj</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="230"/>
        <source>Copy file name only</source>
        <translation>Kopiuj tylko nazwę pliku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="235"/>
        <source>Copy full file path</source>
        <translation>Kopiuj pełną ścieżkę do pliku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="245"/>
        <source>Image quality</source>
        <translation>Jakość obrazów</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="251"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Jakość obrazu (1 — mały plik, 100 — wysoka jakość)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="316"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Wstawianie obecnej daty do nazwy zapisywanego pliku</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="319"/>
        <source>Insert current date and time in file name</source>
        <translation>Wstawiaj datę i godzinę w nazwę plików</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="328"/>
        <source>Template: </source>
        <translation>Szablon: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="353"/>
        <source>Example: </source>
        <translation>Przykład: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="363"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Automatyczny zapis zrzutów ekranu w procesie przechwytywania</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="366"/>
        <source>Autosave screenshot</source>
        <translation>Automatycznie zapisuj zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="378"/>
        <source>Save first screenshot</source>
        <translation>Zapisz pierwszy zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="387"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>Pozwól na uruchamianie wielu kopii ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="390"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>Pozwól na wiele instancji ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="397"/>
        <source>Open in external viewer on double click</source>
        <translation>Otwieraj zewnętrzny podgląd dwukrotnym kliknięciem</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="400"/>
        <source>Enable external viewer</source>
        <translation>Włącz zewnętrzną przeglądarkę</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="407"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>Jeśli nie wybrano, zaznaczony obszar
może zostać powiększony, aby wypełnić do zewnętrznych krawędzi</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="411"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>Dopasuj do krawędzi wewnątrz zaznaczonego obszaru naciskając prawy przycisk myszy</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="418"/>
        <source>Notify on saving and copying</source>
        <translation>Powiadamiaj o zapisywaniu i kopiowaniu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="427"/>
        <source>Duration:</source>
        <translation>Długość:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="494"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>Pokazuj ScreenGrab w zasobniku systemowym</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="434"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="501"/>
        <source>Minimize to tray on click close button</source>
        <translation>Minimalizuj do zasobnika po zamknięciu okna</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="504"/>
        <source>Minimize to tray when closing</source>
        <translation>Minimalizuj do zasobnika przy zamykaniu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="543"/>
        <source>Action</source>
        <translation>Działanie</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="548"/>
        <source>Shortcut</source>
        <translation>Skrót</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="553"/>
        <source>New screen</source>
        <translation>Nowy zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="558"/>
        <source>Save screen</source>
        <translation>Zapisz zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="563"/>
        <source>Copy screen</source>
        <translation>Kopiuj zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="573"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="578"/>
        <source>Quit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="588"/>
        <source>Selected shortcut:</source>
        <translation>Wybrany skrót:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="595"/>
        <source>Not defined</source>
        <translation>Nie zdefiniowano</translation>
    </message>
</context>
</TS>
